NEWS


tximportData 1.41.1

Reduced package size

The package's example data has been cut from ~593 MB on disk (~388 MB compressed) to ~171 MB on disk (~96 MB compressed). The built tarball is now ~96 MiB.

The full data as it was before this change (commit 02887f7) is kept on the with-inf-reps branch and tag at https://github.com/mikelove/tximportData and archived on Zenodo: https://doi.org/10.5281/zenodo.22982575

Removed

Kept

Changes needed in downstream code